<?php
/**
 * Candid Admin Functions
 * 
 * Provides functions for settings and options in the Admin area.
 *
 * @package WordPress
 * @subpackage Candid
 * @author 5 Inline
 */


/**
 * candid_theme_admin_menu()
 * 
 * Register theme options menu in the admin.
 * 
 * @param none
 * @return none
 * @uses action:admin_menu
 */
if( !function_exists('candid_theme_admin_menu') ) :
function candid_theme_admin_menu()
{
	add_theme_page( 
		apply_filters('candid_theme_settings_title', __('Themes Settings','candid_theme')),
		apply_filters('candid_theme_settings_menu', __('Theme Settings','candid_theme')), 
		0, 
		'candid-theme-settings', 
		'candid_theme_settings_page' 
	);
}
add_action( 'admin_menu', 'candid_theme_admin_menu' );
endif;


/**
 * candid_theme_settings_controller()
 * 
 * Action controller for theme settings.
 * 
 * @param none
 * @return none
 * @uses action:admin_init
 */
if( !function_exists('candid_theme_settings_controller') ) :
function candid_theme_settings_controller()
{
	global $candid_theme_options;
	$candid_theme_options = apply_filters('candid_theme_options', $candid_theme_options );

	if( $_POST['save-candid-theme-settings'] ) :
		if( !check_admin_referer('nonce_theme_settings','candid_theme_settings') )
			die('Not verified.');
		
		if( update_option( 'candid_theme_options', $_POST['candid_theme_options'] ) )
			$msg = 1;
		
		foreach( $candid_theme_options as $option ) {
			if( isset($_POST[$option]) )
				update_option( $option, $_POST[$option] );
		}

		wp_safe_redirect( add_query_arg(array('page'=>'candid-theme-settings','message'=>$msg),admin_url('themes.php')) );
	endif;
}
add_action( 'admin_init', 'candid_theme_settings_controller' );
endif;


/**
 * candid_theme_settings_page()
 * 
 * Page for displaying theme settings.
 * 
 * @param none
 * @return none
 * @uses add_theme_page()
 */
if( !function_exists('candid_theme_settings_page') ) :
function candid_theme_settings_page()
{
	$options = get_option('candid_theme_options', TRUE);
	?>
	<div class="wrap">
		<h2>Theme Settings</h2>
		
		<p>Welcome to the Theme Settings. Need some help? Use the "Help" tab above!</p>
		<form action="<?= add_query_arg(array('page'=>'candid-theme-settings'),admin_url('themes.php'));?>" method="post">
			<h3>Portfolio Options</h3>
			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row">
							<label for="portfolio_category"><?= __('Portfolio Category','candid_theme');?></label>
						</th>
						<td>
							<?php
							$args = array
							(
								'hide_empty'	=> 0,
								'show_option_none'	=> '- None -', 
								'name'			=> 'candid_theme_options[portfolio_category]',
								'id'			=> 'portfolio_category',
								'selected'		=> $options['portfolio_category'],
							);
							wp_dropdown_categories( $args );
							?><br /> ONLY posts from this category will be displayed on your homepage portfolio. Each post MUST have a featured image set before it will display.
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="portfolio_count"><?= __('Portfolio Items Count','candid_theme');?></label>
						</th>
						<td>
							<input type="text" name="candid_theme_options[portfolio_count]" id="portfolio_count" value="<?= $options['portfolio_count'];?>" class="small-text" />
							<br />Choose the number of posts you want to display per page on the homepage. (Intervals of <em>3</em> HIGHLY suggested)
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="candid_theme_portfolio_on_blog"><?php _e('Show in Blog','candid_theme');?></label></th>
						<td>
							<input type="checkbox" name="candid_theme_options[on_blog]" id="candid_theme_portfolio_on_blog" value="1"<?= $options['on_blog'] == 1 ? ' checked="checked"' : NULL;?> /> <?php _e('Show portfolio posts in your blog stream.','candid_theme');?>
						</td>
					</tr>
				</tbody>
			</table>
			<h3>Extras Options</h3>
			<table class="form-table">
				<tbody>
					<?php if( !CANDID_THEME_FORCE_SWATCHES ) : ?>
					<tr valign="top">
						<th scope="row"><?php _e('Color Schemes','candid_theme');?></th>
						<td>
							<input type="checkbox" name="candid_theme_options[candid_theme_enable_swatches]" value="1" id="candid_theme_enable_swatches" <?= $options['candid_theme_enable_swatches'] ? ' checked="checked"' : NULL;?> /> <label for="candid_theme_enable_swatches"><?php _e('Enable Color Schemes','candid_theme');?></label>
						</td>
					</tr>
					<?php endif; ?>
					<?php
/*
					if( !CANDID_THEME_FORCE_FANCYBOX ) : ?>
					<tr valign="top">
						<th scope="row"><?php _e('Fancybox','candid_theme');?></th>
						<td>
							<input type="checkbox" name="candid_theme_options[candid_theme_enable_fancybox]" value="1" id="candid_theme_enable_fancybox" <?= $options['candid_theme_enable_fancybox'] ? ' checked="checked"' : NULL;?> /> <label for="candid_theme_enable_fancybox"><?php _e('Enable the Fancybox modal window','candid_theme');?></label>
						</td>
					</tr>
					<?php endif; 
*/					?>
					<?php if( !CANDID_THEME_FORCE_NIVO ) : ?>
					<tr valign="top">
						<th scope="row"><?php _e('Nivo Slider','candid_theme');?></th>
						<td>
							<input type="checkbox" name="candid_theme_options[candid_theme_enable_nivo]" value="1" id="candid_theme_enable_nivo" <?= $options['candid_theme_enable_nivo'] ? ' checked="checked"' : NULL;?> /> <label for="candid_theme_enable_nivo"><?php _e('Enable the Nivo Slider slideshow','candid_theme');?></label>
						</td>
					</tr>
					<?php endif; ?>
					<?php if( !CANDID_THEME_FORCE_GANALYTICS ) : ?>
					<tr valign="top">
						<th scope="row"><?php _e('Google Analytics','candid_theme');?></th>
						<td>
							<input type="checkbox" name="candid_theme_options[candid_theme_enable_ganalytics]" value="1" id="candid_theme_enable_ganalytics" <?= $options['candid_theme_enable_ganalytics'] ? ' checked="checked"' : NULL;?> /> <label for="candid_theme_enable_ganalytics"><?php _e('Enable Google Analytics','candid_theme');?></label>
						</td>
					</tr>
					<?php endif; ?>
					<?php if( !CANDID_THEME_FORCE_CONTACT ) : ?>
					<tr valign="top">
						<th scope="row"><?php _e('Contact Form','candid_theme');?></th>
						<td>
							<input type="checkbox" name="candid_theme_options[candid_theme_enable_contact]" value="1" id="candid_theme_enable_contact" <?= $options['candid_theme_enable_contact'] ? ' checked="checked"' : NULL;?> /> <label for="candid_theme_enable_contact"><?php printf(__('Enable Built-in Contact Form<br /><strong>Note:</strong> To use with your <a href="%s">custom menu</a>, create a "Custom Link" with the URL of "#contact". Or use <code>[quick_contact_form]</code> in a page.','candid_theme'), admin_url('nav-menus.php') );?></label>
						</td>
					</tr>
					<?php endif; ?>
				</tbody>
			</table>
			<?php do_action('candid_theme_option_fields');?>
			<p class="submit">
				<?php wp_nonce_field('nonce_theme_settings', 'candid_theme_settings');?>
				<button type="submit" class="button-primary" name="save-candid-theme-settings" value="save"><?= __('Save Options','candid_theme');?></button>
			</p>
		</form>
	</div>
	<?php
}
endif;

?>