<?php
/**
 * Fancybox Functions
 *
 * @package WordPress
 * @subpackage candid_theme
 * @author 5 Inline
 */


/**
 * fancybox_register_scripts()
 * 
 * Register scripts for Fancybox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('fancybox_register_scripts') ) :
function fancybox_register_scripts()
{
	wp_register_script( 'fancybox', get_bloginfo('template_directory') .'/extras/fancybox/jquery.fancybox-1.3.4.pack.js', array('jquery'), '1.3.4', FALSE );
}
add_action( 'template_redirect', 'fancybox_register_scripts' );
endif;


/**
 * fancybox_enqueue_scripts()
 * 
 * Enqueue scripts for Fancybox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('fancybox_enqueue_scripts') ) :
function fancybox_enqueue_scripts()
{
	wp_enqueue_script( 'fancybox' );
}
add_action( 'template_redirect', 'fancybox_enqueue_scripts' );
endif;


/**
 * fancybox_footer_scripts()
 * 
 * Add script initialization in footer.
 * 
 * @param none
 * @return none
 * @uses action:wp_footer
 */
if( !function_exists('fancybox_footer_scripts') ) :
function fancybox_footer_scripts()
{
	$defaults = array
	(
		'element'				=> '.portfolio-image,.image-link',
		'overlayColor'			=> '#111',
		'showCloseButton'		=> 'true',	
		'showNavArrows'			=> 'true',	
		'enableEscapeButton'	=> 'true',
	);
	$get_options = get_option('fancybox_options');
	$args = wp_parse_args( $get_options, $defaults);
	extract($args);

	$r = array_shift($args);
	foreach( $args as $key=>$val ) {
		$arga[] = "$key:'$val'";
	}
	if( !empty($arga) )
		$argstring = implode(",",$arga);
	
	echo '<script type="text/javascript">'. "\n";
	echo 'jQuery(document).ready( function(){ if( jQuery.isFunction( jQuery.fn.fancybox) ) { $(\''. $element .'\').fancybox({'. $argstring .'}); } }); '."\n";
	echo '</script>'. "\n";
}
add_action( 'wp_footer', 'fancybox_footer_scripts' );
endif;


/**
 * fancybox_register_styles()
 * 
 * Register styles for Fancybox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('fancybox_register_styles') ) :
function fancybox_register_styles()
{
	wp_register_style( 'fancybox', get_bloginfo('template_directory') .'/extras/fancybox/jquery.fancybox-1.3.4.css', array(), '1.3.4', 'screen' );
}
add_action( 'template_redirect', 'fancybox_register_styles' );
endif;


/**
 * fancybox_enqueue_styles()
 * 
 * Enqueue styles for Fancybox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('fancybox_enqueue_styles') ) :
function fancybox_enqueue_styles()
{
	wp_enqueue_style( 'fancybox' );
}
add_action( 'template_redirect', 'fancybox_enqueue_styles' );
endif;


/**
 * fancybox_admin_options()
 * 
 * Admin options form fields for Fancybox.
 * 
 * @param none
 * @return none
 * @uses action:candid_theme_option_fields
 */
if( !function_exists('fancybox_admin_options') ) :
function fancybox_admin_options()
{
	$options = get_option('fancybox_options');
	?>
	<h3>Fancybox Options</h3>
	<table class="form-table">
		<tbody>
			<tr valign="top">
				<th scope="row"><?php _e('Overlay Color','candid_theme')?></th>
				<td>
					<input type="text" name="fancybox_options[overlayColor]" id="fancybox_options_overlayColor" value="<?= $options['overlayColor'];?>" /> Site overlay color
				</td>
			</tr>
		</tbody>
	</table>
	<?php
	
}
add_action( 'candid_theme_option_fields', 'fancybox_admin_options' );
endif;


/**
 * fancybox_options()
 * 
 * Admin options names for Fancybox.
 * 
 * @param none
 * @return none
 * @uses action:candid_theme_options
 */
if( !function_exists('fancybox_options') ) :
function fancybox_options( $options )
{
	array_push($options, 'fancybox_options' );
	return $options;
}
add_filter( 'candid_theme_options', 'fancybox_options' );
endif;
?>