<?php
/**
 * Candid Theme Quick Contact Form
 *
 * @package WordPress
 * @subpackage Candid Theme
 * @author 5 Inline
 */


/**
 * candid_quick_contact_form()
 * 
 * Display contact form.
 * 
 * @param array $args
 * @return none
 * @uses add_shortcode
 */
if( !function_exists('candid_quick_contact_form') ) :
function candid_quick_contact_form( $args = array() )
{
	$defaults = array
	(
	);
	$r = wp_parse_args( $args, $defaults );
	
	
	if( $_GET['quicksend'] == 1 ) {
		_e('Your message was sent.','candid_theme');
	} elseif( $_GET['quicksend'] == 2 ) {
		_e('Your message could not be sent. Please try again later.', 'candid_theme');
	} else {
		do_action('candid_quick_contact_form_before');
		?>
		<div class="line form contact-form">
			<form action="" method="post" id="quick_contact_form">
				<div class="unit g1of2">
					<p><label for="quick_contact_name"><?= __('Your Name','candid_theme');?></label>
						<input type="text" name="contact_form_name" id="quick_contact_name" class="text name" /></p>
					<p><label for="quick_contact_email"><?= __('Your Email','candid_theme');?></label>
						<input type="text" name="contact_form_email" id="quick_contact_email" type="email" class="text email" /></p>
				</div>
				<div class="unit g1of2">
					<label for="quick_contact_message"><?= __('Your Message','candid_theme');?></label>
						<textarea name="contact_form_message" id="quick_contact_message" rows="4" cols="30" class="text message"></textarea>
					<button type="submit" class="button submit" name="send_quick_contact" id="quick_contact_button">Send</button>
					<?php wp_nonce_field('send_quick_contact','quick_contact_nonce');?>
				</div>
			</form>
		</div>
		<?php
		do_action('candid_quick_contact_form_after');
	}
}
add_shortcode( 'quick_contact_form', 'candid_quick_contact_form' );
endif;


if( !function_exists('candid_quick_contact_ajax') ) :
function candid_quick_contact_ajax()
{
	$response = candid_quick_contact_send();
	switch( $response ) {
		case 1 :
			$message = __('<h4 class="line grid7 msg">Your message has been sent!</h4>','candid_theme');
			break;
		case 2 :
			$message = __('<h4 class="line grid7 msg">Your message could not be sent.</h4>', 'candid_theme');
			break;
	}
	$output = array(
		'status'	=> $response,
		'data'		=> $message,
	);
	echo json_encode($output);
	die('');
}
add_action( 'wp_ajax_quick-contact-send-form', 'candid_quick_contact_ajax' );
add_action( 'wp_ajax_nopriv_quick-contact-send-form', 'candid_quick_contact_ajax' );
endif;

/**
 * candid_quick_contact_controller()
 * 
 * Action controller for contact form.
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('candid_quick_contact_controller') ) :
function candid_quick_contact_controller()
{
	if( isset($_POST['send_quick_contact']) )
	{
		$msg = candid_quick_contact_send();
		wp_redirect( add_query_arg( array('quicksend'=>$msg) , get_permalink() ) );
	}
}
add_action( 'template_redirect', 'candid_quick_contact_controller' );
endif;


/**
 * candid_quick_contact_send()
 * 
 * Process sending contact form information.
 * 
 * @param array $args
 * @return bool
 */
if( !function_exists('candid_quick_contact_send') ) :
function candid_quick_contact_send( $args = array() )
{
	$data = empty($_POST) ? $_GET : $_POST;
	// Check nonce
	if( !wp_verify_nonce($data['quick_contact_nonce'],'send_quick_contact') )
		return 2;
	
	// Check email
	if( !is_email($data['contact_form_email']) )
		return 2;
		
	$to = get_option('admin_email');
	$from_name = esc_attr($data['contact_form_name']);
	$from_email = $data['contact_form_email'];
	$from_message = $data['contact_form_message'];
	$headers = 'From: '. $from_name .' <'. $from_email .'>'. "\r\n";
	
	$options = get_option( 'quickcontact_options', TRUE );
	$subject = $options['subject'] ? $options['subject'] : get_option('blogname') .' Contact Form';
	
	//
	// Check with Akismet
	//
	if( function_exists('akismet_http_post') && $key = get_option('wordpress_api_key') ) {
		$akismet_api_host = $key . '.rest.akismet.com';
		$akismet_api_port = 80;

		$defaults = array
		(
			'comment_author'		=> $from_name,
			'comment_author_email'	=> $from_email,
			'comment_content'		=> $from_message,
			'user_ip'				=> $_SERVER['REMOTE_ADDR'],
			'user_agent'			=> $_SERVER['HTTP_USER_AGENT'],
			'blog'					=> get_option('home'),
		    'blog_lang'				=> get_locale(),
		    'blog_charset'			=> get_option('blog_charset'),
		    'permalink'  			=> get_permalink(),	    
		);
		$r = wp_parse_args( $args, $defaults );

		$query_string = '';
		foreach ( $r as $key=>$data )
			$query_string .= $key . '=' . urlencode( stripslashes($data) ) . '&';
	    $response = akismet_http_post($query_string, $akismet_api_host, '/1.1/comment-check', $akismet_api_port);
		if( $response[1] != 'true' ) 
			$msg = wp_mail( $to, $subject, $from_message, $headers ) ? 1 : 2;
	} else {
		$msg = wp_mail( $to, $subject, $from_message, $headers ) ? 1 : 2;
	}
	return $msg;
//	wp_redirect( add_query_arg( array('quicksend'=>$msg) , get_permalink() ) );
}
endif;


/**
 * candid_quick_contact_styles()
 * 
 * Load styles specifically for quick contact.
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('candid_quick_contact_styles') ) :
function candid_quick_contact_styles()
{
	$suffix = (CANDID_THEME_DEV == TRUE) ? '' : '.min';
	wp_enqueue_style('quick-contact', get_bloginfo('template_directory') .'/extras/quickcontact/quickcontact'. $suffix .'.css', array('theme','grid','type','reset'), _dev_ver('1.0') );
}
add_action( 'template_redirect', 'candid_quick_contact_styles', 10 );
endif;


/**
 * candid_quick_contact_scripts()
 * 
 * Load scripts specifically for quick contact.
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('candid_quick_contact_scripts') ) :
function candid_quick_contact_scripts()
{
	$suffix = (CANDID_THEME_DEV == TRUE) ? '' : '.min';
	wp_enqueue_script('quick-contact', get_bloginfo('template_directory') .'/extras/quickcontact/quickcontact'. $suffix .'.js', array('jquery'), _dev_ver('1.0') );
	wp_localize_script('quick-contact', 'quick_contact_settings', array('ajaxurl'=>admin_url('admin-ajax.php') ) ) ;
}
add_action( 'template_redirect', 'candid_quick_contact_scripts', 11 );
endif;


/**
 * candid_quick_contact_slidedown()
 * 
 * Slidedown inline contact form.
 * 
 * @param none
 * @return none
 * @uses action:wp_footer
 */
if( !function_exists('candid_quick_contact_slidedown') ) :
function candid_quick_contact_slidedown()
{
	?>
	<div class="line grid960 middle nomargin contact-slider">
		<div class="unit grid4 contact-widget-wrapper">
			<?php if( !dynamic_sidebar('quick-contact-widget') ) { printf(__('<a href="%s">Edit the Quick Contact Widget</a> to put additional contact info like your Twitter account, Facebook profile, or LinkedIn profile.','candid_theme'), admin_url('widgets.php') ); } ?>
		</div>
		<div class="unit grid8 contact-form-wrapper">
			<?= candid_quick_contact_form();?>
		</div>
	</div>
	<?php
}
add_action( 'wp_footer', 'candid_quick_contact_slidedown' );
endif;


/**
 * candid_quick_contact_widgets_init()
 * 
 * Register widget area for quick contact.
 * 
 * @param none
 * @return none
 * @uses action:widgets_init
 */
if( !function_exists('candid_quick_contact_widgets_init') ) :
function candid_quick_contact_widgets_init()
{
	register_sidebar( array(
		'name' => __( 'Quick Contact Widget Area', 'candid_theme' ),
		'id' => 'quick-contact-widget',
		'description' => __( 'Quick Contact Widget Area', 'candid_theme' ),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '',
		'after_title' => '',
	) );
}
add_action( 'widgets_init', 'candid_quick_contact_widgets_init' );
endif;


?>