<?php
/**
 * Shadowbox Functions
 *
 * @package WordPress
 * @subpackage candid_theme
 * @author 5 Inline
 */


/**
 * shadowbox_register_scripts()
 * 
 * Register scripts for Shadowbox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('shadowbox_register_scripts') ) :
function shadowbox_register_scripts()
{
	wp_register_script( 'shadowbox', get_bloginfo('template_directory') .'/extras/shadowbox/shadowbox.js', array('jquery'), '3.0.3', FALSE );
}
add_action( 'template_redirect', 'shadowbox_register_scripts' );
endif;


/**
 * shadowbox_enqueue_scripts()
 * 
 * Enqueue scripts for Shadowbox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('shadowbox_enqueue_scripts') ) :
function shadowbox_enqueue_scripts()
{
	wp_enqueue_script( 'shadowbox' );
}
add_action( 'template_redirect', 'shadowbox_enqueue_scripts' );
endif;


/**
 * shadowbox_footer_scripts()
 * 
 * Add script initialization in footer.
 * 
 * @param none
 * @return none
 * @uses action:wp_footer
 */
if( !function_exists('shadowbox_footer_scripts') ) :
function shadowbox_footer_scripts()
{
	$defaults = array
	(
		'element'				=> '.portfolio-image,.image-link',
		'continuous'			=> 'TRUE',
	);
	$get_options = get_option('shadowbox_options');
	$args = wp_parse_args( $get_options, $defaults);
	extract($args);

	$r = array_shift($args);
	foreach( $args as $key=>$val ) {
		$arga[] = "$key:'$val'";
	}
	if( !empty($arga) )
		$argstring = implode(",",$arga);
	
	echo '<script type="text/javascript">'. "\n";
	echo 'Shadowbox.init({ skipSetup: true });'. "\n";
	echo 'jQuery(document).ready( function(){  Shadowbox.setup(\''. $element .'\',{'. $argstring .'}); }); '."\n";
	echo '</script>'. "\n";
}
add_action( 'wp_footer', 'shadowbox_footer_scripts' );
endif;


/**
 * shadowbox_register_styles()
 * 
 * Register styles for Shadowbox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('shadowbox_register_styles') ) :
function shadowbox_register_styles()
{
	wp_register_style( 'shadowbox', get_bloginfo('template_directory') .'/extras/shadowbox/shadowbox.css', array(), '3.0.3', 'screen' );
}
add_action( 'template_redirect', 'shadowbox_register_styles' );
endif;


/**
 * shadowbox_enqueue_styles()
 * 
 * Enqueue styles for Shadowbox
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('shadowbox_enqueue_styles') ) :
function shadowbox_enqueue_styles()
{
	wp_enqueue_style( 'shadowbox' );
}
add_action( 'template_redirect', 'shadowbox_enqueue_styles' );
endif;


/**
 * shadowbox_admin_options()
 * 
 * Admin options form fields for Shadowbox.
 * 
 * @param none
 * @return none
 * @uses action:candid_theme_option_fields
 */
if( !function_exists('shadowbox_admin_options') ) :
function shadowbox_admin_options()
{
	$options = get_option('shadowbox_options');
	?>
	<h3>Shadowbox Options</h3>
	<table class="form-table">
		<tbody>
			<tr valign="top">
				<th scope="row"><?php _e('Overlay Color','candid_theme')?></th>
				<td>
					<input type="text" name="shadowbox_options[overlayColor]" id="shadowbox_options_overlayColor" value="<?= $options['overlayColor'];?>" /> <?= __('Modal window overlay color, in hex (#000000)','candid_theme');?>
				</td>
			</tr>
		</tbody>
	</table>
	<?php
	
}
add_action( 'candid_theme_option_fields', 'shadowbox_admin_options' );
endif;


/**
 * shadowbox_options()
 * 
 * Admin options names for Shadowbox.
 * 
 * @param none
 * @return none
 * @uses action:candid_theme_options
 */
if( !function_exists('shadowbox_options') ) :
function shadowbox_options( $options )
{
	array_push($options, 'shadowbox_options' );
	return $options;
}
add_filter( 'candid_theme_options', 'shadowbox_options' );
endif;
?>