<?php
/**
 * Theme Functions
 *
 * @package WordPress
 * @subpackage Candid
 * @author 5 Inline
 * @version 1.0
 */

/**
 * Definitions.
 */
define( 'CANDID_THEME_DEV', TRUE );
define( 'CANDID_THEME_VER', '1.0' );
define( 'CANDID_THEME_PATH', dirname(__FILE__) );
define( 'CANDID_THEME_STYLES',	get_bloginfo('template_directory') . '/styles' );
define( 'CANDID_THEME_SCRIPTS',	get_bloginfo('template_directory') .'/scripts' );
define( 'CANDID_THEME_IMAGES',	get_bloginfo('template_directory') .'/images' );

/**
 * Options.
 */
global $candid_theme_options;
$candid_theme_options = apply_filters( 'candid_theme_options', array
(
	'candid_theme_enable_fancybox',
	'candid_theme_enable_nivo',
	'candid_theme_enable_ganalytics',
	'candid_theme_enable_swatches',
));
define( 'CANDID_THEME_FORCE_FANCYBOX', FALSE );
define( 'CANDID_THEME_FORCE_SHADOWBOX', TRUE );
define( 'CANDID_THEME_FORCE_NIVO', TRUE );
define( 'CANDID_THEME_FORCE_GANALYTICS', FALSE );
define( 'CANDID_THEME_FORCE_SWATCHES', TRUE );
define( 'CANDID_THEME_FORCE_CONTACT', FALSE );


/**
 * candid_theme_setup()
 * 
 * Run when the theme is setup.
 * 
 * @param none
 * @return none
 * @uses action:after_setup_theme
 */
if( !function_exists('candid_theme_setup') ) :
function candid_theme_setup()
{
	// Remove WordPress Generated <head> content.
	remove_action( 'wp_head', 'wp_generator' );
	remove_action( 'wp_head', 'feed_links', 2 );
	remove_action( 'wp_head', 'feed_links_extra', 3 );
	remove_action( 'wp_head', 'rsd_link' );
	remove_action( 'wp_head', 'wlwmanifest_link' );
	remove_action( 'wp_head', 'index_rel_link' );
	remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
	remove_action( 'wp_head', 'locale_stylesheet' );
	remove_action( 'wp_head', 'rel_canonical' );
	
	// Admin.
	if( is_admin() ) {
		include_once( CANDID_THEME_PATH .'/admin.php' );
	}

	// Extras.
	$options = get_option( 'candid_theme_options' );
	if( ( $options['candid_theme_enable_fancybox'] || CANDID_THEME_FORCE_FANCYBOX == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/fancybox/fancybox.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/fancybox/fancybox.php' );
	}
	if( ( $options['candid_theme_enable_nivo'] || CANDID_THEME_FORCE_NIVO == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/nivo/nivo.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/nivo/nivo.php' );
	}
	if( ( $options['candid_theme_enable_ganalytics'] || CANDID_THEME_FORCE_GANALYTICS == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/analytics/analytics.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/analytics/analytics.php' );
	}
	if( ( $options['candid_theme_enable_swatches'] || CANDID_THEME_FORCE_SWATCHES == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/swatches/swatches.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/swatches/swatches.php' );
	}
	if( ( $options['candid_theme_enable_contact'] || CANDID_THEME_FORCE_CONTACT == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/quickcontact/quickcontact.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/quickcontact/quickcontact.php' );
	}
	if( ( $options['candid_theme_enable_shadowbox'] || CANDID_THEME_FORCE_SHADOWBOX == TRUE ) && ( file_exists(CANDID_THEME_PATH .'/extras/shadowbox/shadowbox.php') ) ) {
		include_once( CANDID_THEME_PATH .'/extras/shadowbox/shadowbox.php' );
	}
	

	// Add theme supports.
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );

	// Navigation menus.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'candid_theme' ),
	));

	// Images and thumbnails.
	define( 'HEADER_IMAGE_WIDTH', '300' );
	define( 'HEADER_IMAGE_HEIGHT', '120' );
	define( 'NO_HEADER_TEXT', true );
	add_image_size( 'portfolio-thumb', 300, 380, TRUE );
	add_image_size( 'slideshow-thumb', 940, 480, TRUE );
	add_image_size( 'single-thumb', 602, 400, FALSE );
	add_custom_image_header( '', 'candid_theme_admin_header_style' );
	
	if( is_admin() ) {
		include_once( CANDID_THEME_PATH .'/admin.php' );
	}

	// Prepare rewrites
	global $wp_rewrite;
	$wp_rewrite->flush_rules();
}
function candid_theme_admin_header_style(){}
add_action( 'after_setup_theme', 'candid_theme_setup' );
endif;


/**
 * candid_theme_widgets_init()
 * 
 * Register widgets for theme.
 * 
 * @param none
 * @return none
 * @uses action:widgets_init
 */
if( !function_exists('candid_theme_widgets_init') ) :
function candid_theme_widgets_init()
{
	register_sidebar( array(
		'name' => __( 'Page Widget Area', 'my_theme' ),
		'id' => 'page-widget',
		'description' => __( 'Widget area to be displayed on Pages', 'my_theme' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Blog Widget Area', 'my_theme' ),
		'id' => 'blog-widget',
		'description' => __( 'Widget area to be displayed on Blog', 'my_theme' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Header Welcome Text', 'my_theme' ),
		'id' => 'welcome-text',
		'description' => __( 'Welcome text displayed in the header', 'my_theme' ),
		'before_widget' => '<div class="line grid960 middle welcome-text %2$s"><hr class="hr" />',
		'after_widget' => '<hr class="hr" /></div>',
		'before_title' => '',
		'after_title' => '',
	) );
}
add_action( 'widgets_init', 'candid_theme_widgets_init' );
endif;


/**
 * candid_theme_default_menu()
 * 
 * Default navigation menu if a user-customized one isn't defined.
 * 
 * @param array $args
 * @return string
 */
if( !function_exists('candid_theme_default_menu') ) :
function candid_theme_default_menu( $args ) {
	
	$menu_items[] = array
	(
		'link'	=> home_url('/'),
		'label'	=> 'Home',
		'title'	=> '',
	);
	$menu_items[] = array
	(
		'link'	=> get_permalink_slug('about'),
		'label'	=> 'About',
		'title'	=> '',
	);
	$menu_items[] = array
	(
		'link'	=> '/blog',
		'label'	=> 'Blog',
		'title'	=> '',
	);
	$menu_items[] = array
	(
		'link'	=> '#contact',
		'label'	=> 'Contact',
		'title'	=> '',
	);

	$string = '<ul class="'. $args['menu_class'] .'">'. "\n";
	foreach( $menu_items as $item ) :
		$string .= '<li class="unit nav-item"><a href="'. $item['link'] .'" title="'. esc_attr($item['title']) .'">'. $item['label'] .'</a></li>'.  "\n";
	endforeach;
	$string .= '</ul>';
	echo $string;
}
endif;


/**
 * _dev_ver()
 * 
 * In version numbering for dev mode.
 * 
 * @param string $ver
 * @return string
 */
if( !function_exists('_dev_ver') ) :
function _dev_ver( $ver = THEME_VER, $dev = THEME_DEV )
{
	$return = ($dev == TRUE) ? time() : $ver;
	return $return;
}
endif;


/**
 * candid_theme_head()
 * 
 * Add content to the <head> tag.
 * 
 * @param none
 * @return none
 * @uses action:wp_head
 */
if( !function_exists('candid_theme_head') ) :
function candid_theme_head()
{
	echo '<meta name="viewport" content="width=device-width; initial-scale=1.0">'."\n";
}
add_action( 'wp_head', 'candid_theme_head' );
endif;


/**
 * candid_theme_footer()
 * 
 * Add content to the footer.
 * 
 * @param none
 * @return none
 * @uses action:wp_footer
 */
if( !function_exists('candid_theme_footer') ) :
function candid_theme_footer()
{
}
add_action( 'wp_footer', 'candid_theme_footer' );
endif;


/**
 * candid_theme_register_styles()
 * 
 * Register default stylesheets.
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('candid_theme_register_styles') ) :
function candid_theme_register_styles()
{
	$suffix = (CANDID_THEME_DEV == TRUE) ? '' : '.min';
	wp_register_style( 'reset', 'http://yui.yahooapis.com/3.1.1/build/cssreset/reset-min.css', array(), '3.1.1', 'all' );
	wp_register_style( 'grid', CANDID_THEME_STYLES .'/grid'. $suffix .'.css', array(), _dev_ver(CANDID_THEME_VER), 'all' );
	wp_register_style( 'type', CANDID_THEME_STYLES .'/type'. $suffix .'.css', array(), _dev_ver(CANDID_THEME_VER), 'all' );
	wp_register_style( 'theme', CANDID_THEME_STYLES .'/theme'. $suffix .'.css', array('reset','grid','type'), _dev_ver(CANDID_THEME_VER), 'all' );
}
add_action( 'template_redirect', 'candid_theme_register_styles' );
endif;

/**
 * candid_theme_enqueue_styles()
 * 
 * Enqueue stylesheets for usage in theme.
 * 
 * @param none
 * @return none
 * @uses action:wp_print_styles
 */
if( !function_exists('candid_theme_enqueue_styles') ) :
function candid_theme_enqueue_styles()
{
	wp_enqueue_style( 'reset' );
	wp_enqueue_style( 'grid' );
	wp_enqueue_style( 'type' );
	wp_enqueue_style( 'theme' );
}
add_action( 'template_redirect', 'candid_theme_enqueue_styles', 11 );
endif;


/**
 * candid_theme_register_scripts()
 * 
 * Register default scripts.
 * 
 * @param none
 * @return none
 * @uses action:template_redirect
 */
if( !function_exists('candid_theme_register_scripts') ) :
function candid_theme_register_scripts()
{
	$suffix = (CANDID_THEME_DEV == TRUE) ? '' : '.min';
	wp_deregister_script( 'jquery' );
	wp_register_script( 'jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery'. $suffix .'.js', array(), '1.4.2', FALSE );

	wp_deregister_script( 'jquery-ui' );
	wp_register_script( 'jquery-ui', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.4/jquery-ui'. $suffix .'.js', array('jquery'), '1.8.4', FALSE );

	wp_deregister_script( 'common' );
	wp_register_script( 'common', get_bloginfo('template_directory') .'/scripts/jquery.common'. $suffix .'.js', array('jquery'), _dev_ver('1.0'), FALSE );
	
	wp_register_script( 'theme', get_bloginfo('template_directory') .'/scripts/theme'. $suffix .'.js', array('jquery'), _dev_ver(), FALSE );
}
add_action( 'template_redirect', 'candid_theme_register_scripts' );
endif;


/**
 * candid_theme_enqueue_scripts()
 * 
 * Enqueue scripts for usage in theme.
 * 
 * @param none
 * @return none
 * @uses action:wp_print_scripts
 */
if( !function_exists('candid_theme_enqueue_scripts') ):
function candid_theme_enqueue_scripts()
{
	if( !is_admin() ) :
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'common' );
		wp_enqueue_script( 'theme' );
	endif;
}
add_action( 'template_redirect', 'candid_theme_enqueue_scripts', 11 );
endif;


/**
 * _rewrite_rules_array()
 * 
 * Modify rewrite rules to find all courses in a nice url.
 * 
 * @param array $rules
 * @return array
 * @uses filter:rewrite_rules_array
 */
if( !function_exists('candid_theme_rewrite_rules_array')) :
function candid_theme_rewrite_rules_array( $rules )
{
	$new = array
	(
		'blog/?$'				=> 'index.php?taxonomy=category&term=all&cpage=blog',
	);
	return $new + $rules;
}
add_filter( 'rewrite_rules_array', 'candid_theme_rewrite_rules_array' );
endif;


/**
 * _query_vars()
 * 
 * Assign custom query variables.
 * 
 * @param array $vars
 * @return array
 * @uses action:query_vars
 */
if( !function_exists('candid_query_vars') ) :
function candid_query_vars( $vars )
{
	$vars[] = 'cpage';
	return $vars;
}
add_filter( 'query_vars', 'candid_query_vars' );
endif;

/**
 * _parse_query()
 * 
 * Parse query to look for "all" term to aggregate all posts in that particular taxonomy.
 * 
 * @param object $query
 * @return object
 * @uses action:parse_query
 */
if( !function_exists('candid_theme_parse_query') ) :
function candid_theme_parse_query( $query )
{
	if( $query->query_vars['term'] == 'all' ) :
		global $wp_taxonomies;
		if( function_exists('get_terms') ) :
			$terms = get_terms($query->query_vars['taxonomy'], array('hide_empty'=>0));
			foreach( $terms as $term ) :
				$term_slugs[] = $term->slug;
			endforeach;
			if( !empty($terms) )
				$terms = implode(',',$term_slugs);
			$taxonomy = $wp_taxonomies[$query->query_vars['taxonomy']];

			$query->query['term'] = $terms;
			$query->query_vars['term'] = $terms;
			$query->query_vars['post_type'] = implode(',',$taxonomy->object_type);
		endif;
	endif;
	return $query;
}
add_action( 'parse_request', 'candid_theme_parse_query' );
endif;


/**
 * _posts_where()
 * 
 * Modify post query to accommodate multiple custom taxonomy terms.
 * 
 * @param string $where
 * @return string
 * @uses filter:posts_where
 */
if( !function_exists('candid_posts_where') ) :
function candid_posts_where( $where )
{
	global $wp_query, $wpdb;
	$options = get_option('candid_theme_options', TRUE);
	$nivo_options = get_option('nivo_options', TRUE);
	if( strpos($wp_query->query_vars['term'],',') !== FALSE && strpos($where,'AND 0') !== FALSE ) :
		$term_array = explode(',',$wp_query->query_vars['term']);
		foreach( $term_array as $term_item ) :
			$term = get_terms($wp_query->query_vars['taxonomy'], array('slug'=>$term_item));
			if( !$options['on_blog'] && $term[0]->term_id == $options['portfolio_category'] )
				continue;
			if( !$nivo_options['on_blog'] && $term[0]->term_id == $nivo_options['slideshow_category'] )
				continue;
			$term_ids[] = $term[0]->term_id;
		endforeach;
//*			
		$post_ids = get_objects_in_term($term_ids, $wp_query->query_vars['taxonomy']);
		if( !is_wp_error($post_ids) && count($post_ids) ) :
			$new_where = "AND {$wpdb->posts}.ID IN (". implode(',',$post_ids) .") ";
			$where = str_replace("AND 0 ", $new_where, $where);
		endif;
/**/
	endif;
	return $where;
}
add_filter( 'posts_where', 'candid_posts_where' );
endif;



/**
 * _wp_title()
 * 
 * Modify wp_title function to display title when "all" term is selected for a taxonomy.
 * 
 * @param string $title
 * @param string $sep
 * @param string $seplocation
 * @return string
 * @uses filter:wp_title
 */
if( !function_exists('candid_wp_title') ) :
function candid_wp_title( $title, $sep = ' | ', $seplocation = 'right' )
{
	global $wp_query;
	if( is_tax() ) :
		$tax = get_query_var('taxonomy');
		$taxonomy = get_taxonomy($tax);
		$name = get_query_var('term');
		if( get_query_var('cpage') == 'blog' )
			echo 'Blog';

		if( $name == 'all' ) :
			$prefix = " $sep ";
			$t_sep = '%WP_TITILE_SEP%';
			$title = $taxonomy->labels->all_items;
			if ( 'right' == $seplocation ) { // sep on right, so reverse the order
				$title_array = explode( $t_sep, $title );
				$title_array = array_reverse( $title_array );
				$title = implode( " $sep ", $title_array ) . $prefix;
			} else {
				$title_array = explode( $t_sep, $title );
				$title = $prefix . implode( " $sep ", $title_array );
			}
		endif;
	endif;
	return $title;
}
add_filter( 'wp_title', 'candid_wp_title' );
endif;


/**
 * _dev_ver()
 * 
 * In version numbering for dev mode.
 * 
 * @param string $ver
 * @return string
 */
if( !function_exists('_dev_ver') ) :
function _dev_ver( $ver = CANDID_THEME_VER, $dev = CANDID_THEME_VER )
{
	$return = ($dev == TRUE) ? time() : $ver;
	return $return;
}
endif;


/**
 * remove_recent_comments()
 * 
 * Remove recent comments widget inline style.
 * 
 * @param none
 * @return none
 * @uses action:widgets_init
 */
if( !function_exists('remove_recent_comments') ) :
function remove_recent_comments()
{
	global $wp_widget_factory;
	remove_action( 'wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style') );
}
add_action( 'widgets_init', 'remove_recent_comments' );
endif;



/**
 * nice_meta_title()
 * 
 * Outputs nice format for the <title> element in the <head> meta.
 * 
 * @param string $sep
 * @return none
 */
if( !function_exists('nice_meta_title') ) :
function nice_meta_title( $sep = '|' )
{
	global $page, $paged;
	wp_title( $sep, true, 'right' );
	bloginfo( 'name' );
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " $sep $site_description";
	if ( $paged >= 2 || $page >= 2 )
		echo " $sep " . sprintf( __( 'Page %s', 'i5' ), max( $paged, $page ) );
}
endif;


/**
 * get_permalink_slug()
 * 
 * Get a page link by the slug.
 * 
 * @param string slug
 * @return string
 */
if( !function_exists('get_permalink_slug') ) :
function get_permalink_slug( $slug )
{
	$args = array('name'=>$slug,'posts_per_page'=>1,'post_type'=>'any');
	$get_post = new WP_Query();
	if( $posts = $get_post->query($args) )
		return get_permalink( $posts[0]->ID );
	return "#";
}
endif;


/**
 * permalink_shortcode()
 * 
 * Allow usage of dynamic permalinks in post content.
 * 
 * @param array $atts
 * @return string
 * @uses add_shortcode, get_permalink_slug
 */
if( !function_exists('permalink_shortcode') ) :
function permalink_shortcode( $atts, $content = '' )
{
	$defaults = array
	(
		'id'	=> '1',
		'text'	=> '',
		'slug'	=> '',
	);
	extract( shortcode_atts($defaults, $atts) );
	$url = empty($slug) ? get_permalink($id) : get_permalink_slug($slug);

	if( !empty($content) ) {
		$link = sprintf('<a href="%1$s">%2$s</a>', $url, $content );
	} elseif( !empty($text) ) {
		$link = sprintf('<a href="%1$s">%2$s</a>', $url, $text );
	} else {
		$link = $url;
	}
	return $link;
}
add_shortcode( 'permalink', 'permalink_shortcode' );
endif;


/**
 * bloginfo_shortcode()
 * 
 * Get bloginfo attributes in post content.
 * 
 * @param array $atts
 * @return string
 * @uses add_shortcode
 */
if( !function_exists('bloginfo_shortcode') ) :
function bloginfo_shortcode( $atts )
{
	if( is_string( $atts ) )
		$atts = explode(' ', $atts, 2 );
	$atts = (array)$atts;
	$show = array_shift($atts);
	
	return get_bloginfo( $show );
}
add_shortcode( 'bloginfo', 'bloginfo_shortcode' );
endif;


/**
 * time_sensitive_shortcode()
 * 
 * Set a date time to display/hide specific blocks of content in a post.
 * 
 * @param array $atts
 * @param string $content
 * @return string
 * @uses add_shortcode()
 */
if( !function_exists('content_timer') ) :
function content_timer( $atts, $content = '' )
{
	$defaults = array
	(
		'show'	=> time(),
		'hide'	=> null,
		'text'	=> '',
	);
	extract( shortcode_atts($defaults, $atts) );
	$to_show = is_string($show) ? strtotime($show) : $show;
	$to_hide = is_string($hide) ? strtotime($hide) : current_time('timestamp') + 1576800000; // 50 Years Out
	
	if( current_time('timestamp') >= $to_show && current_time('timestamp') <= $to_hide ) {
		return $content;
	}
	return '';
}
add_shortcode( 'timer', 'content_timer' );
endif;


/**
 * candid_theme_help_menu()
 * 
 * Display help content in contextual help menu.
 * 
 * @param string $contextual_help
 * @param string $screen_id
 * @param string $screen
 * @uses action:contextual_help
 */
function candid_theme_help_menu( $contextual_help, $screen_id = '', $screen = '' )
{
	if( $screen_id == 'appearance_page_candid-theme-settings' ) {
		$contextual_help = sprintf(__('<h3>Welcome to the Candid Theme</h3><p>This is a great theme for photographers to easily display their portfolio in a stylish and usable manor.</p>
		<p><strong>Getting Started</strong></p>
		<ul>
		<li>There are 2 sections for displaying your portfolio, the slideshow and the portfolio items. The slideshow should be designated for your "featured" items. You can control the display of these by <a href="%1$s">setting up separate categories</a> for featured items and portfolio items, then selecting the appropriate category below.</li>
		<li>If you DO NOT want your portfolio posts to show up in your Blog, check the appropriate check boxes below.</li>
		<li>The portfolio items are displayed in rows of 3 columns, so it is HIGHLY SUGGESTED that your Portfolio Items Count in intervals of 3.</li>
		<li>There is a <strong>Welcome Text</strong> area on your homepage. It is setup as a widget, so if the widget is not setup, text does not display. You can configure it <a href="%2$s">in the Widgets panel</a> if you would like to welcome your visitors.</li>
		</ul>','candid_theme'), admin_url('edit-tags.php?taxonomy=category'), admin_url('widgets.php') );
	}
	return $contextual_help;
}
add_action( 'contextual_help', 'candid_theme_help_menu', 10, 3 );
?>