/**
 * Core Common Javascript Functions
 * 
 * Commonly used javascript functions. 
 * 
 * @package WordPress
 * @subpackage Candid
 * @author 5 Inline
 */

/**
 * placeHolder()
 * 
 * Display default form values using the label tag.
 * 
 * usage $(label).labelClear();
 */
jQuery.fn.extend({
	placeHolder : function(options)
	{
		return this.each(function()
		{
			new jQuery.placeHolder(this,options);
		});
	}
});
(function($) {
jQuery.placeHolder = function( el, options )
{
	var detect = navigator.userAgent.toLowerCase(); 
	if( detect.indexOf('webkit') > 0 ) return false;
	options = $.extend({
		classname : 'placeholder'
	}, options || {});
	
	var text =  $(el).attr('placeholder');
	if( text == undefined ) return false;
	
	var placeholder = $('<div>').text(text);
	if( options.classname ) {
		$(placeholder).addClass(options.classname);
	}
	$(el).before(placeholder);

	if( $(el).val() == '' ) {
		$(placeholder).css('visibility','visible');
	}
	$(placeholder).click( function() {
		$(this).css('visibility','hidden'); $(el).focus();
	});
	$(el).blur( function()
	{
		if( this.value == '' ) {
			$(placeholder).css('visibility','visible');
		}
	}).focus( function()
	{
		$(placeholder).css('visibility','hidden');
	}).keydown( function(e)
	{
		$(placeholder).css('visibility','hidden');
		$(this).unbind(e);
	});
	
}
})(jQuery);


/**
 * dropDown()
 * 
 * Drop down navigation.
 * 
 * usage $(element).dropDown(options);
 */
jQuery.fn.extend({
	dropDown : function(options)
	{
		return this.each(function()
		{
			new jQuery.dropDown(this, options);
		});
	}
});
(function($) {
jQuery.dropDown = function( el, options )
{
	options = $.extend({
		onEvent: 'mouseover',
		offEvent: 'mouseout',
		speed: null,
		child: 'ul',
		activeClass: 'active'
	},
    options || {});

	$(el).children(options.child).hide();
	$(el).bind( options.onEvent, function()
	{
		$(this).children(options.child).show(options.speed);
		$(this).addClass(options.activeClass);
	}).bind( options.offEvent, function()
	{
		$(this).children(options.child).hide(options.speed);
		$(this).removeClass(options.activeClass);
	});
}	
})(jQuery);


/**
 * rollover()
 * 
 * Image rollovers for elements.
 * 
 * usage $(element).rollover(options);
 */
jQuery.fn.extend({
	rollover : function(options)
	{
		return this.each(function()
		{
			new jQuery.rollover(this,options);
		});
	}
});
(function($) {
jQuery.rollover = function( el, options )
{
	options = $.extend({
		suffix: '_over',
		onEvent: 'mouseover',
		offEvent: 'mouseout',
		activeClass: 'over'
	},
    options || {});
	
	var srcString = $(el).attr('src');
	var ext = srcString.substring(srcString.length - 4, srcString.length), name = srcString.substring(0, srcString.length - 4), overImage = name + options.suffix + ext;
	var img = new Image();	img.src = overImage;
	$(el).bind( options.onEvent, function()
	{
		$(this).addClass(options.activeClass).attr('src',overImage);
	}).bind( options.offEvent, function()
	{
		$(this).removeClass(options.activeClass).attr('src',srcString);
	});
}
})(jQuery);


/**
 * popwindow()
 * 
 * Open a new window at the specified size.
 * 
 * usage $(element).popwindow(options);
 */
jQuery.fn.extend({
	popwindow : function(options)
	{
		return this.each( function()
		{
			new jQuery.popwindow(this,options);
		});
	}
});
(function($) {
jQuery.popwindow = function( el, options )
{
	options = $.extend({
		width: '640',
		height: '360',
		toolbar: 0,
		menubar: 0, 
		scrollbars: 1, 
		resizable: 1,
		copyhistory: 0,
		location: 0, 
		directories: 0, 
		status: 1,
		titlebar: 1, 
		personalbar: 0
	},
    options || {});
	
	if( !options.width && !options.height ) {
		var classname = $(el).attr('class');
		if( classname.length > 0 ) {
			var dimensions = className.match(/[0-9]{1,4}x[0-9]{1,4}/) + '';
			options.width = eval(dimensions.split('x')[0]), options.height = eval(dimensions.split('x')[1]);
		}
	}
	$(el).bind( 'click', function() 
	{ 
		window.open("" + $(el).attr('href') + "",null,'width=' + options.width + ', height=' + options.height +', toolbar='+ options.toolbar +', menubar='+ options.menubar +', scrollbars='+ options.scrollbars +', resizable='+ options.resizable +', copyhistory='+ options.copyhistory +', location='+ options.location +', directories='+ options.directories +', status='+ options.status +', title='+ options.titlebar +', personalbar='+ options.personalbar); 
		return false; 
	});
}
})(jQuery);


/**
 * cookie()
 *
 * Cookie management in JS.
 * 
 * usage: cookie.set(), cookie.get(), cookie.remove()
 */
var cookie = {
	set : function( name, value, expires, path, domain, secure )
	{
		var today = new Date();
		today.setTime( today.getTime() );
		if( expires )
			expires = expires * 1000 * 60 * 60 * 24;
		var expires_date = new Date( today.getTime() + expires );
		document.cookie = name +'='+ escape(value) + 
			( expires	? ';expires='+ expires_date.toGMTString() : '' ) +
			( path		? ';path='+ path : '' ) +
			( domain	? ';domain='+ domain : '' ) +
			( secure	? ';secure' : '' );

	},
	get : function( name )
	{
		var start = document.cookie.indexOf( name + "=" );
		var len = start + name.length + 1;
		if ( ( !start ) && ( name != document.cookie.substring( 0, name.length ) ) ) {
			return null;
		}
		if ( start == -1 )
			return null;
		var end = document.cookie.indexOf( ';', len );
		if ( end == -1 )
			end = document.cookie.length;
		return unescape( document.cookie.substring( len, end ) );
	},
	remove : function( name, path, domain ) {
		if ( cookies.get( name ) ) document.cookie = name + '=' +
			( ( path ) ? ';path=' + path : '') +
			( ( domain ) ? ';domain=' + domain : '' ) +
			';expires=Thu, 01-Jan-1970 00:00:01 GMT';
	}
}